==> react-native-scanbot-sdk-6.1.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/models/ScanbotBarcodeScannerModels.kt <==
package io.scanbot.sdk.reactnative.models

import android.graphics.Color
import androidx.annotation.Keep
import io.scanbot.sdk.AspectRatio
import io.scanbot.sdk.barcode.entity.BarcodeDocumentFormat
import io.scanbot.sdk.barcode.entity.BarcodeFormat
import io.scanbot.sdk.barcode.entity.EngineMode
import io.scanbot.sdk.barcode.entity.Gs1Handling
import io.scanbot.sdk.barcode.entity.MSIPlesseyChecksumAlgorithm
import io.scanbot.sdk.barcode.ui.BarcodeOverlayTextFormat
import io.scanbot.sdk.camera.ZoomRange
import io.scanbot.sdk.ui.configuration.json.JsonBarcodesExtensionFilter


@Keep
data class DetectorConfig(
    val barcodeFormats: List<BarcodeFormat>? = listOf(),
    val acceptedDocumentFormats: List<BarcodeDocumentFormat>? = listOf(),
    val engineMode: EngineMode? =  EngineMode.NextGen,
    val barcodesExtensionFilter: JsonBarcodesExtensionFilter? = JsonBarcodesExtensionFilter.NO_FILTER,
    // Additional Config
    val lowPowerMode: Boolean? = false,
    val minimumTextLength: Int? = 0,
    val maximumTextLength: Int? = 0,
    val minimum1DBarcodesQuietZone: Int? = 0,
    val stripCheckDigits: Boolean? = false,
    val gs1HandlingMode: Gs1Handling? = Gs1Handling.PARSE,
    val msiPlesseyChecksumAlgorithm: MSIPlesseyChecksumAlgorithm? = MSIPlesseyChecksumAlgorithm.Mod10
)

class PolygonStyleConfig(
    strokeColor: Int? = null,
    strokeHighlightedColor: Int? = null,
    fillColor: Int? = null,
    fillHighlightedColor: Int? = null
) {
    companion object {
        val DEFAULT_STROKE_COLOR = Color.parseColor("#CC00CFA6")
        val DEFAULT_STROKE_HIGHLIGHTED_COLOR = Color.parseColor("#CCC81A3C")
        val DEFAULT_FILL_COLOR = Color.parseColor("#3300CFA6")
        val DEFAULT_FILL_HIGHLIGHTED_COLOR = Color.parseColor("#33C81A3C")
    }

    var strokeColor: Int? = strokeColor
        get() = field ?: DEFAULT_STROKE_COLOR

    var strokeHighlightedColor: Int? = strokeHighlightedColor
        get() = field ?: DEFAULT_STROKE_HIGHLIGHTED_COLOR

    var fillColor: Int? = fillColor
        get() = field ?: DEFAULT_FILL_COLOR

    var fillHighlightedColor: Int? = fillHighlightedColor
        get() = field ?: DEFAULT_FILL_HIGHLIGHTED_COLOR

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as PolygonStyleConfig

        if (strokeColor != other.strokeColor) return false
        if (strokeHighlightedColor != other.strokeHighlightedColor) return false
        if (fillColor != other.fillColor) return false
        if (fillHighlightedColor != other.fillHighlightedColor) return false

        return true
    }

    override fun hashCode(): Int {
        var result = strokeColor ?: 0
        result = 31 * result + (strokeHighlightedColor ?: 0)
        result = 31 * result + (fillColor ?: 0)
        result = 31 * result + (fillHighlightedColor ?: 0)
        return result
    }
}

class TextStyleConfig(
    textColor: Int? = null,
    textHighlightedColor: Int? = null,
    textContainerColor: Int? = null,
    textContainerHighlightedColor: Int? = null,
    textFormat: BarcodeOverlayTextFormat? = null
) {
    companion object {
        const val DEFAULT_TEXT_COLOR = Color.BLACK
        const val DEFAULT_TEXT_HIGHLIGHTED_COLOR = Color.WHITE
        val DEFAULT_TEXT_CONTAINER_COLOR = Color.parseColor("#CC00CFA6")
        val DEFAULT_TEXT_CONTAINER_HIGHLIGHTED_COLOR = Color.parseColor("#CCC81A3C")
        val DEFAULT_TEXT_FORMAT = BarcodeOverlayTextFormat.CODE_AND_TYPE
    }

    var textColor: Int? = textColor
        get() = field ?: DEFAULT_TEXT_COLOR

    var textHighlightedColor: Int? = textHighlightedColor
        get() = field ?: DEFAULT_TEXT_HIGHLIGHTED_COLOR

    var textContainerColor: Int? = textContainerColor
        get() = field ?: DEFAULT_TEXT_CONTAINER_COLOR

    var textContainerHighlightedColor: Int? = textContainerHighlightedColor
        get() = field ?: DEFAULT_TEXT_CONTAINER_HIGHLIGHTED_COLOR

    var textFormat: BarcodeOverlayTextFormat? = textFormat
        get() = field ?: DEFAULT_TEXT_FORMAT

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as TextStyleConfig

        if (textColor != other.textColor) return false
        if (textHighlightedColor != other.textHighlightedColor) return false
        if (textContainerColor != other.textContainerColor) return false
        if (textContainerHighlightedColor != other.textContainerHighlightedColor) return false
        if (textFormat != other.textFormat) return false

        return true
    }

    override fun hashCode(): Int {
        var result = textColor ?: 0
        result = 31 * result + (textHighlightedColor ?: 0)
        result = 31 * result + (textContainerColor ?: 0)
        result = 31 * result + (textContainerHighlightedColor ?: 0)
        result = 31 * result + (textFormat?.hashCode() ?: 0)
        return result
    }
}

object FinderViewConfiguration {
    const val DEFAULT_STROKE_COLOR = Color.WHITE
    val DEFAULT_OVERLAY_COLOR = Color.parseColor("#A9000000")
    const val DEFAULT_FINDER_ENABLED = false
    const val DEFAULT_STROKE_WIDTH = 2
    const val DEFAULT_FINDER_MIN_PADDING = 66
    val DEFAULT_FINDER_INSETS = FinderInsets(10, 10, 10, 10)
    val DEFAULT_ASPECT_RATIO = listOf(AspectRatio(4.0, 3.0))
}

object CameraConfiguration {
    val DEFAULT_ZOOM_RANGE = ZoomRange(1f, 12f)
}

@Keep
data class SelectedBarcodes(
    val textWithExtension: String,
    val type: BarcodeFormat
)

@Keep
data class ZoomRangeConfig(
    var minZoom: Float,
    var maxZoom: Float,
)

@Keep
data class FinderInsets(
    var left: Int,
    var right: Int,
    var top: Int,
    var bottom: Int
)

==> react-native-scanbot-sdk-6.2.1.tgz: package/android/src/main/java/io/scanbot/sdk/reactnative/models/ScanbotBarcodeScannerModels.kt <==
package io.scanbot.sdk.reactnative.models

import android.graphics.Color
import androidx.annotation.Keep
import io.scanbot.sdk.AspectRatio
import io.scanbot.sdk.barcode.entity.BarcodeDocumentFormat
import io.scanbot.sdk.barcode.entity.BarcodeFormat
import io.scanbot.sdk.barcode.entity.EngineMode
import io.scanbot.sdk.barcode.entity.Gs1Handling
import io.scanbot.sdk.barcode.entity.MSIPlesseyChecksumAlgorithm
import io.scanbot.sdk.barcode.ui.BarcodeOverlayTextFormat
import io.scanbot.sdk.camera.ZoomRange
import io.scanbot.sdk.reactnative.extensions.Utils
import io.scanbot.sdk.ui.configuration.json.JsonBarcodesExtensionFilter


@Keep
data class DetectorConfig(
    val barcodeFormats: List<BarcodeFormat>? = listOf(),
    val acceptedDocumentFormats: List<BarcodeDocumentFormat>? = listOf(),
    val engineMode: EngineMode? = EngineMode.NextGen,
    val barcodesExtensionFilter: JsonBarcodesExtensionFilter? = JsonBarcodesExtensionFilter.NO_FILTER,
    // Additional Config
    val lowPowerMode: Boolean? = false,
    val minimumTextLength: Int? = 0,
    val maximumTextLength: Int? = 0,
    val minimum1DBarcodesQuietZone: Int? = 0,
    val stripCheckDigits: Boolean? = false,
    val gs1HandlingMode: Gs1Handling? = Gs1Handling.PARSE,
    val msiPlesseyChecksumAlgorithm: MSIPlesseyChecksumAlgorithm? = MSIPlesseyChecksumAlgorithm.Mod10
)

class PolygonStyleConfig(
    strokeColor: Int? = null,
    fillColor: Int? = null,
) {
    companion object {
        val DEFAULT_STROKE_COLOR = Color.parseColor("#CC00CFA6")
        val DEFAULT_FILL_COLOR = Color.parseColor("#3300CFA6")
    }

    var strokeColor: Int? = strokeColor
        get() = field ?: DEFAULT_STROKE_COLOR

    var fillColor: Int? = fillColor
        get() = field ?: DEFAULT_FILL_COLOR

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as PolygonStyleConfig

        if (strokeColor != other.strokeColor) return false
        if (fillColor != other.fillColor) return false

        return true
    }

    override fun hashCode(): Int {
        var result = strokeColor ?: 0
        result = 31 * result + (fillColor ?: 0)
        return result
    }
}

class TextStyleConfig(
    textColor: Int? = null,
    textContainerColor: Int? = null,
    textFormat: BarcodeOverlayTextFormat? = null
) {
    companion object {
        const val DEFAULT_TEXT_COLOR = Color.BLACK
        val DEFAULT_TEXT_CONTAINER_COLOR = Color.parseColor("#CC00CFA6")
        val DEFAULT_TEXT_FORMAT = BarcodeOverlayTextFormat.CODE_AND_TYPE
    }

    var textColor: Int? = textColor
        get() = field ?: DEFAULT_TEXT_COLOR

    var textContainerColor: Int? = textContainerColor
        get() = field ?: DEFAULT_TEXT_CONTAINER_COLOR

    var textFormat: BarcodeOverlayTextFormat? = textFormat
        get() = field ?: DEFAULT_TEXT_FORMAT

    override fun equals(other: Any?): Boolean {
        if (this === other) return true
        if (javaClass != other?.javaClass) return false

        other as TextStyleConfig

        if (textColor != other.textColor) return false
        if (textContainerColor != other.textContainerColor) return false
        if (textFormat != other.textFormat) return false

        return true
    }

    override fun hashCode(): Int {
        var result = textColor ?: 0
        result = 31 * result + (textContainerColor ?: 0)
        result = 31 * result + (textFormat?.hashCode() ?: 0)
        return result
    }
}

object FinderViewConfiguration {
    const val DEFAULT_STROKE_COLOR = Color.WHITE
    val DEFAULT_OVERLAY_COLOR = Color.parseColor("#A9000000")
    const val DEFAULT_FINDER_ENABLED = false
    const val DEFAULT_STROKE_WIDTH = 2
    const val DEFAULT_FINDER_MIN_PADDING = 66
    val DEFAULT_FINDER_INSETS = FinderInsets(10, 10, 10, 10)
    val DEFAULT_ASPECT_RATIO = listOf(AspectRatio(4.0, 3.0))
}

object CameraConfiguration {
    val DEFAULT_ZOOM_RANGE = ZoomRange(1f, 12f)
}

@Keep
data class ZoomRangeConfig(
    var minZoom: Float,
    var maxZoom: Float,
)

@Keep
data class FinderInsets(
    var left: Int,
    var right: Int,
    var top: Int,
    var bottom: Int
)

@Keep
data class BarcodeItemOverlayViewConfig(
    var text: String? = null,
    var textColor: String? = null,
    var textContainerColor: String? = null,
    var polygonColor: String? = null,
    var strokeColor: String? = null,
) {

    val textColorParsed: Int?
        get() = textColor?.let { Utils.tryToParseRGBAHexColor(it) }

    val textContainerColorParsed: Int?
        get() = textContainerColor?.let { Utils.tryToParseRGBAHexColor(it) }

    val polygonColorParsed: Int?
        get() = polygonColor?.let { Utils.tryToParseRGBAHexColor(it) }

    val strokeColorParsed: Int?
        get() = strokeColor?.let { Utils.tryToParseRGBAHexColor(it) }

    companion object {
        var LOADING_TEXT: String? = null
    }
}
